util

package
v0.0.0-...-5341101 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 25, 2020 License: MIT Imports: 5 Imported by: 0

Documentation

Overview

simple util functions until I find a library I'd rather use

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Map2Array

func Map2Array(m map[string]string) [][]string

Map2Array returns 2 dimensional array from the provided map m

func MaxLen

func MaxLen(s1, s2 string) int

MaxLen returns the length of the longest of the strings s1 and s2

func Pad

func Pad(s string, l int) string

Pad returns a string of length l containing string s

func ReplaceVariables

func ReplaceVariables(raw string, subVals map[string]string) string

ReplaceVariables returns a string with all variables marked with double curly brackets based on the provided map of values

func SortArray

func SortArray(unsorted [][]string) [][]string

func StringOf

func StringOf(c rune, l int) string

StringOf returns a string of length l with rune c

Types

This section is empty.

Jump to