Documentation
¶
Overview ¶
simple util functions until I find a library I'd rather use
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ReplaceVariables ¶
ReplaceVariables returns a string with all variables marked with double curly brackets based on the provided map of values
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.